@@ -3,16 +3,18 @@ Utilities imported from ipython_genutils
 """
 
 import re
-from textwrap import dedent, indent as _indent
 import textwrap
+from textwrap import dedent
+from textwrap import indent as _indent
+from typing import List
 
 
-def indent(val):
+def indent(val: str) -> str:
     res = _indent(val, "    ")
     return res
 
 
-def wrap_paragraphs(text: str, ncols=80):
+def wrap_paragraphs(text: str, ncols: int = 80) -> List[str]:
     """Wrap multiple paragraphs to fit a specified width.
 
     This is equivalent to textwrap.wrap, but with support for multiple
